<?php
// $Id: 

// Settings for the Layoutstudio theme

/**
* Implementation of THEMEHOOK_settings() function.
*
* @param $saved_settings
*   array An array of saved settings for this theme.
* @return
*   array A form array.
*/
function layoutstudio_settings($saved_settings) {

	// Add the form's CSS
  drupal_add_css(drupal_get_path('theme', 'layoutstudio') . '/css/theme-settings.css', 'theme');

  /*
   * The default values for the theme variables.
   */
  $defaults = layoutstudio_theme_get_default_settings('layoutstudio');

  // Merge the saved variables and their default values
  $settings = array_merge($defaults, $saved_settings);

  // Create the form widgets using Forms API
  $form['layoutstudio_random_class'] = array(
    '#type' => 'textfield',
    '#title' => t('Body and Block class from random-1 to n'),
    '#default_value' => $settings['layoutstudio_random_class'],
    '#description' => t('This random number will appear as a body/block class that can be used to make a site more dynamic with CSS. For example, can be useful for creating header with rotating images on refresh. <strong>Value needs to be greater than one.</strong>'),
    '#weight' => '-1',
  );

  $form['layoutstudio_layouts'] = array(
    '#type' => 'fieldset',
    '#title' => t('Select Layout'),
    '#description' => t('<p>Choose a site layout for the Primary, Secondary and Tertiary regions.<p>
      <p style="margin-bottom: 0;">Color reference for Primary, Secondary & Tertiary regions:</p>
      <ul class="color-reference layouts">
            <li class="primary-region">Primary</li>
            <li class="secondary-region">Secondary</li>
            <li class="tertiary-region">Tertiary</li>
      </ul class="color-reference">
    '),
    '#collapsible' => FALSE,
  );

  $layout_path = drupal_get_path("theme","MYTHEME")."/css/layouts";
  $form['layoutstudio_layouts']['layoutstudio_layout'] = array(
    '#type' => 'radios',
    '#options' => array(
      "layout1" => t('<strong>Layout #1</strong>') . '<div class="layout-example layout-1"><div class="secondary-region"></div><div class="primary-region">1</div><div class="tertiary-region"></div></div>' . t('<p class="layout-type")>Three column layout with secondary on the left and tertiary on the right of the main content area.</p>'),
      "layout2" => t('<strong>Layout #2</strong>') . '<div class="layout-example layout-2"><div class="tertiary-region"></div><div class="primary-region">2</div><div class="secondary-region"></div></div>' . t('<p class="layout-type")>Three column layout with tertiary on the left and secondary on the right of the main content area.</p>'),
      "layout3" => t('<strong>Layout #3</strong>') . '<div class="layout-example layout-3"><div class="primary-region">3</div><div class="secondary-region"></div><div class="tertiary-region"></div></div>' . t('<p class="layout-type")>Three column layout with secondary and tertiary to the right of the main content area.</p>'),
      "layout4" => t('<strong>Layout #4</strong>') . '<div class="layout-example layout-4"><div class="primary-region">4</div><div class="tertiary-region"></div><div class="secondary-region"></div></div>' . t('<p class="layout-type")>Three column layout with tertiary and secondary to the right of the main content area.</p>'),
      "layout5" => t('<strong>Layout #5</strong>') . '<div class="layout-example layout-5"><div class="secondary-region"></div><div class="tertiary-region"></div><div class="primary-region">5</div></div>' . t('<p class="layout-type")>Three column layout with secondary and tertiary on the left of the main content area.</p>'),
      "layout6" => t('<strong>Layout #6</strong>') . '<div class="layout-example layout-6"><div class="tertiary-region"></div><div class="secondary-region"></div><div class="primary-region">6</div></div>' . t('<p class="layout-type")>Three column layout with tertiary and secondary on the left of the main content area.</p>'),
      "layout7" => t('<strong>Layout #7</strong>') . '<div class="layout-example layout-7"><div class="primary-region">7</div><div class="secondary-region"></div><div class="tertiary-region"></div></div>' . t('<p class="layout-type")>Secondary and tertiary as two columns below main content area.</p>'),
      "layout8" => t('<strong>Layout #8</strong>') . '<div class="layout-example layout-8"><div class="primary-region">8</div><div class="secondary-region"></div><div class="tertiary-region"></div></div>' . t('<p class="layout-type")>No columns. Primary, secondary and tertiary display full width in semantic order.</p>'),
    ),
    '#default_value' => $settings['layoutstudio_layout'],
    '#attributes' => array('class' => 'layouts'),
  );

  $form['layoutstudio_dimensions'] = array(
    '#type' => 'fieldset',
    '#title' => t('Set Dimensions'),
    '#description' => t('<p>Choose dimensions for a Page and for the Secondary and Tertiary regions of the site.'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  $form['layoutstudio_dimensions']['layoutstudio_page_width'] = array(
    '#type' => 'textfield',
    '#title' => t('Page width'),
    '#description' => t('Enter the desired width of the page, in pixels.'),
    '#required' => TRUE,
    '#default_value' => $settings['layoutstudio_page_width'],
    '#field_suffix' => t('px'),
  );

  $form['layoutstudio_dimensions']['layoutstudio_secondary_width'] = array(
    '#type' => 'textfield',
    '#title' => t('Secondary region width'),
    '#description' => t('Enter the desired width of the Secondary region, in pixels.'),
    '#required' => FALSE,
    '#default_value' => $settings['layoutstudio_secondary_width'],
    '#field_suffix' => t('px'),
  );

  $form['layoutstudio_dimensions']['layoutstudio_tertiary_width'] = array(
    '#type' => 'textfield',
    '#title' => t('Tertiary region width'),
    '#description' => t('Enter the desired width of the Tertiary region, in pixels.'),
    '#required' => FALSE,
    '#default_value' => $settings['layoutstudio_tertiary_width'],
    '#field_suffix' => t('px'),
  );

  $form['layoutstudio_header_footer'] = array(
    '#type' => 'fieldset',
    '#title' => t('Header & Footer width'),
    '#description' => t('<p>Choose if you want the header and footer to take up the entire width of the browser window.'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  $form['layoutstudio_header_footer']['layoutstudio_header_width'] = array(
    '#type' => 'checkbox',
    '#title' => t('Make header take full browser width'),
    '#required' => FALSE,
    '#default_value' => $settings['layoutstudio_header_width'],
  );

  $form['layoutstudio_header_footer']['layoutstudio_footer_width'] = array(
    '#type' => 'checkbox',
    '#title' => t('Make footer take full browser width'),
    '#required' => FALSE,
    '#default_value' => $settings['layoutstudio_footer_width'],
  );

  drupal_add_js(
    "
    Drupal.behaviors.layoutstudioThemeSettings = function(context) {
      $('input[name=layoutstudio_layout]').change(function() {
        if ($(this).attr('checked')) {
          var layout = $(this).attr('value');

          if (layout == 'layout7') {
            $('#edit-layoutstudio-secondary-width-wrapper').show();
            $('#edit-layoutstudio-tertiary-width-wrapper').hide();
          }
          else if (layout == 'layout8') {
            $('#edit-layoutstudio-secondary-width-wrapper').hide();
            $('#edit-layoutstudio-tertiary-width-wrapper').hide();
          }
          else {
            $('#edit-layoutstudio-secondary-width-wrapper').show();
            $('#edit-layoutstudio-tertiary-width-wrapper').show();
          }
        }
      });
    }
    ",
    "inline"
  );
      
  // Return the additional form widgets
  return $form;
}

/**
 * Return the theme settings' default values from the .info and save them into the database.
 *
 * @param $theme
 *   The name of theme.
 */
function layoutstudio_theme_get_default_settings($theme) {
  $themes = list_themes();

  // Get the default values from the .info file.
  $defaults = !empty($themes[$theme]->info['settings']) ? $themes[$theme]->info['settings'] : array();

  if (!empty($defaults)) {
    // Get the theme settings saved in the database.
    $settings = theme_get_settings($theme);
    // Don't save the toggle_node_info_ variables.
    if (module_exists('node')) {
      foreach (node_get_types() as $type => $name) {
        unset($settings['toggle_node_info_' . $type]);
      }
    }
    // Save default theme settings.
    variable_set(
      str_replace('/', '_', 'theme_' . $theme . '_settings'),
      array_merge($defaults, $settings)
    );
    // If the active theme has been loaded, force refresh of Drupal internals.
    if (!empty($GLOBALS['theme_key'])) {
      theme_get_setting('', TRUE);
    }
  }

  // Return the default settings.
  return $defaults;
}